"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UtilCreateSnippet = void 0;
const chalk_1 = __importDefault(require("chalk"));
const fs_1 = __importDefault(require("fs"));
const recursive_readdir_1 = __importDefault(require("recursive-readdir"));
const utils_1 = require("../../utils");
class UtilCreateSnippet {
    snippet;
    config;
    prompt;
    path;
    args;
    constructor() {
        this.snippet = new utils_1.UtilSnippet();
        this.prompt = new utils_1.UtilPrompt();
        this.config = new utils_1.UtilConfig().generate();
        this.path = new utils_1.UtilPath();
        this.args = {
            snippet: '',
            name: '',
            path: '',
            isFlat: false,
        };
    }
    async start() {
        try {
            const args = await this.prompt.getArgs();
            this.args = { ...this.args, ...args };
            const { snippet, name, path, isFlat } = this.args;
            const config = this.config.find((item) => item.snippet === snippet);
            if (!config)
                throw new Error('config');
            if (snippet === '')
                throw new Error(`specify the required argument snippet=example`);
            if (name === '')
                throw new Error(`specify the required argument name=example`);
            if (path === '')
                throw new Error(`specify the required argument path=example`);
            (0, recursive_readdir_1.default)(config.files, (error, paths) => {
                if (error)
                    throw new Error(error.message);
                paths.forEach((pathToSnippet) => {
                    const formattedSnippet = this.snippet.format({ pathToSnippet, name });
                    const generatePath = this.path.generate({
                        pathToSnippet,
                        config,
                        name,
                        path,
                    });
                    if (fs_1.default.existsSync(generatePath.pathWriteSnippetFile))
                        throw new Error(name);
                    this.snippet.create({ ...generatePath, formattedSnippet, isFlat });
                });
            });
        }
        catch (e) {
            // eslint-disable-next-line no-console
            console.log(chalk_1.default.red(e));
        }
    }
}
exports.UtilCreateSnippet = UtilCreateSnippet;
